@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2019 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2020 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -65,7 +65,9 @@ Q_GADGET
             KindLocalization,
             KindService,
             KindRepository,
-            KindOperatingSystem
+            KindOperatingSystem,
+            KindIconTheme,
+            KindRuntime
         };
         Q_ENUM(Kind)
 
@@ -179,6 +181,7 @@ Q_GADGET
         QStringList categories() const;
         void addCategory(const QString& category);
         bool hasCategory(const QString& category) const;
+        bool isMemberOfCategory(const AppStream::Category& category) const;
 
         QStringList extends() const;
         void setExtends(const QStringList& extends);
@@ -231,6 +234,9 @@ Q_GADGET
         uint searchMatches(const QString& term) const;
         uint searchMatchesAll(const QStringList& terms) const;
 
+        uint sortScore() const;
+        void setSortScore(uint score);
+
         MergeKind mergeKind() const;
         void setMergeKind(MergeKind kind);
 
@@ -242,7 +248,8 @@ Q_GADGET
         AppStream::ContentRating contentRating(const QString& kind) const;
         void addContentRating(const AppStream::ContentRating& contentRating);
 
-        bool isMemberOfCategory(const AppStream::Category& category) const;
+        QString nameVariantSuffix() const;
+        void setNameVariantSuffix(const QString& variantSuffix, const QString& lang = {});
 
         bool isIgnored() const;
         bool isValid() const;
